import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGateway::DomainName`` resource specifies a custom domain name for your API in API Gateway.
 *  You can use a custom domain name to provide a URL that's more intuitive and easier to recall. For more information about using custom domain names, see [Set up Custom Domain Name for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-custom-domains.html) in the *API Gateway Developer Guide*.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const cfnDomainName = config.require("cfnDomainName");
 * const certificateArn = config.require("certificateArn");
 * const type = config.require("type");
 * const myDomainName = new aws_native.apigateway.DomainName("myDomainName", {
 *     certificateArn: certificateArn,
 *     domainName: cfnDomainName,
 *     endpointConfiguration: {
 *         types: [type],
 *     },
 *     regionalCertificateArn: certificateArn,
 * });
 * export const domainName = myDomainName.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const cfnDomainName = config.require("cfnDomainName");
 * const certificateArn = config.require("certificateArn");
 * const type = config.require("type");
 * const myDomainName = new aws_native.apigateway.DomainName("myDomainName", {
 *     certificateArn: certificateArn,
 *     domainName: cfnDomainName,
 *     endpointConfiguration: {
 *         types: [type],
 *     },
 *     regionalCertificateArn: certificateArn,
 * });
 * export const domainName = myDomainName.id;
 *
 * ```
 */
export declare class DomainName extends pulumi.CustomResource {
    /**
     * Get an existing DomainName resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DomainName;
    /**
     * Returns true if the given object is an instance of DomainName.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainName;
    /**
     * The reference to an AWS -managed certificate that will be used by edge-optimized endpoint or private endpoint for this domain name. AWS Certificate Manager is the only supported source.
     */
    readonly certificateArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon CloudFront distribution domain name that's mapped to the custom domain name. This is only applicable for endpoints whose type is `EDGE` .
     *
     * Example: `d111111abcdef8.cloudfront.net`
     */
    readonly distributionDomainName: pulumi.Output<string>;
    /**
     * The region-agnostic Amazon Route 53 Hosted Zone ID of the edge-optimized endpoint. The only valid value is `Z2FDTNDATAQYW2` for all regions.
     */
    readonly distributionHostedZoneId: pulumi.Output<string>;
    /**
     * The custom domain name as an API host name, for example, `my-api.example.com` .
     */
    readonly domainName: pulumi.Output<string | undefined>;
    readonly domainNameArn: pulumi.Output<string>;
    /**
     * The endpoint configuration of this DomainName showing the endpoint types and IP address types of the domain name.
     */
    readonly endpointConfiguration: pulumi.Output<outputs.apigateway.DomainNameEndpointConfiguration | undefined>;
    /**
     * The mutual TLS authentication configuration for a custom domain name. If specified, API Gateway performs two-way authentication between the client and the server. Clients must present a trusted certificate to access your API.
     */
    readonly mutualTlsAuthentication: pulumi.Output<outputs.apigateway.DomainNameMutualTlsAuthentication | undefined>;
    /**
     * The ARN of the public certificate issued by ACM to validate ownership of your custom domain. Only required when configuring mutual TLS and using an ACM imported or private CA certificate ARN as the RegionalCertificateArn.
     */
    readonly ownershipVerificationCertificateArn: pulumi.Output<string | undefined>;
    /**
     * The reference to an AWS -managed certificate that will be used for validating the regional domain name. AWS Certificate Manager is the only supported source.
     */
    readonly regionalCertificateArn: pulumi.Output<string | undefined>;
    /**
     * The domain name associated with the regional endpoint for this custom domain name. You set up this association by adding a DNS record that points the custom domain name to this regional domain name.
     */
    readonly regionalDomainName: pulumi.Output<string>;
    /**
     * The region-specific Amazon Route 53 Hosted Zone ID of the regional endpoint.
     */
    readonly regionalHostedZoneId: pulumi.Output<string>;
    /**
     * The Transport Layer Security (TLS) version + cipher suite for this DomainName. The valid values are `TLS_1_0` and `TLS_1_2` .
     */
    readonly securityPolicy: pulumi.Output<string | undefined>;
    /**
     * The collection of tags. Each tag element is associated with a given resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DomainName resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DomainNameArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DomainName resource.
 */
export interface DomainNameArgs {
    /**
     * The reference to an AWS -managed certificate that will be used by edge-optimized endpoint or private endpoint for this domain name. AWS Certificate Manager is the only supported source.
     */
    certificateArn?: pulumi.Input<string>;
    /**
     * The custom domain name as an API host name, for example, `my-api.example.com` .
     */
    domainName?: pulumi.Input<string>;
    /**
     * The endpoint configuration of this DomainName showing the endpoint types and IP address types of the domain name.
     */
    endpointConfiguration?: pulumi.Input<inputs.apigateway.DomainNameEndpointConfigurationArgs>;
    /**
     * The mutual TLS authentication configuration for a custom domain name. If specified, API Gateway performs two-way authentication between the client and the server. Clients must present a trusted certificate to access your API.
     */
    mutualTlsAuthentication?: pulumi.Input<inputs.apigateway.DomainNameMutualTlsAuthenticationArgs>;
    /**
     * The ARN of the public certificate issued by ACM to validate ownership of your custom domain. Only required when configuring mutual TLS and using an ACM imported or private CA certificate ARN as the RegionalCertificateArn.
     */
    ownershipVerificationCertificateArn?: pulumi.Input<string>;
    /**
     * The reference to an AWS -managed certificate that will be used for validating the regional domain name. AWS Certificate Manager is the only supported source.
     */
    regionalCertificateArn?: pulumi.Input<string>;
    /**
     * The Transport Layer Security (TLS) version + cipher suite for this DomainName. The valid values are `TLS_1_0` and `TLS_1_2` .
     */
    securityPolicy?: pulumi.Input<string>;
    /**
     * The collection of tags. Each tag element is associated with a given resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
