import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Specifies the properties for creating a launch template.
 *  The minimum required properties for specifying a launch template are as follows:
 *   +  You must specify at least one property for the launch template data.
 *   +  You can optionally specify a name for the launch template. If you do not specify a name, CFN creates a name for you.
 *
 *  A launch template can contain some or all of the configuration information to launch an instance. When you launch an instance using a launch template, instance properties that are not specified in the launch template use default values, except the ``ImageId`` property, which has no default value. If you do not specify an AMI ID for the launch template ``ImageId`` property, you must specify an AMI ID for the instance ``ImageId`` property.
 *  For more information, see [Launch an instance from a launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html) in the *Amazon EC2 User Guide*.
 */
export declare class LaunchTemplate extends pulumi.CustomResource {
    /**
     * Get an existing LaunchTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LaunchTemplate;
    /**
     * Returns true if the given object is an instance of LaunchTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LaunchTemplate;
    /**
     * The default version of the launch template, such as 2.
     *
     * The default version of a launch template cannot be specified in AWS CloudFormation . The default version can be set in the Amazon EC2 console or by using the `modify-launch-template` AWS CLI command.
     */
    readonly defaultVersionNumber: pulumi.Output<string>;
    /**
     * The latest version of the launch template, such as `5` .
     */
    readonly latestVersionNumber: pulumi.Output<string>;
    /**
     * The information for the launch template.
     */
    readonly launchTemplateData: pulumi.Output<outputs.ec2.LaunchTemplateData>;
    /**
     * The ID of the launch template.
     */
    readonly launchTemplateId: pulumi.Output<string>;
    /**
     * A name for the launch template.
     */
    readonly launchTemplateName: pulumi.Output<string | undefined>;
    /**
     * The tags to apply to the launch template on creation. To tag the launch template, the resource type must be ``launch-template``.
     *  To specify the tags for resources that are created during instance launch, use [TagSpecifications](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html#cfn-ec2-launchtemplate-launchtemplatedata-tagspecifications).
     */
    readonly tagSpecifications: pulumi.Output<outputs.ec2.LaunchTemplateTagSpecification[] | undefined>;
    /**
     * A description for the first version of the launch template.
     */
    readonly versionDescription: pulumi.Output<string | undefined>;
    /**
     * Create a LaunchTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LaunchTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LaunchTemplate resource.
 */
export interface LaunchTemplateArgs {
    /**
     * The information for the launch template.
     */
    launchTemplateData: pulumi.Input<inputs.ec2.LaunchTemplateDataArgs>;
    /**
     * A name for the launch template.
     */
    launchTemplateName?: pulumi.Input<string>;
    /**
     * The tags to apply to the launch template on creation. To tag the launch template, the resource type must be ``launch-template``.
     *  To specify the tags for resources that are created during instance launch, use [TagSpecifications](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html#cfn-ec2-launchtemplate-launchtemplatedata-tagspecifications).
     */
    tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateTagSpecificationArgs>[]>;
    /**
     * A description for the first version of the launch template.
     */
    versionDescription?: pulumi.Input<string>;
}
